@@ -3,28 +3,22 @@ from vista_api_client.api_resources.api_resource import ApiResource, HttpMethods
 
 
 class Roles(ApiResource):
-    def list(self, environment):
+    def list(self):
         return self.dispatch('/v1/roles', HttpMethods.GET, {
-            'environment': environment,
+            'branch': self.branch,
         })
 
-    def create(self, role_id, grants, parent_roles, environment):
+    def create(self, role_id, actions_by_resource_type, parent_roles):
         return self.dispatch('/v1/roles', HttpMethods.POST, {
             'role_id': role_id,
-            'grants': grants,
+            'actions_by_resource_type': actions_by_resource_type,
             'parent_roles': parent_roles,
-            'environment': environment,
+            'branch': self.branch,
         })
 
-    def listUsersetsForRole(self, role_id, environment):
-        return self.dispatch(f"/v1/roles/{role_id}/usersets", HttpMethods.GET, {
-            'role_id': role_id,
-            'environment': environment,
-        })
-
-    def inherit(self, child_role_id, parent_role_id, environment):
+    def inherit(self, child_role_id, parent_role_id):
         return self.dispatch('/v1/roles/inherit', HttpMethods.POST, {
             'child_role_id': child_role_id,
             'parent_role_id': parent_role_id,
-            'environment': environment,
+            'branch': self.branch,
         })
